@@ -90,22 +90,14 @@ class curse():
                             msg = f"{word} is already in the list."
                         await ctx.send(msg, delete_after=5)
                         return
-        await db.close()
-        if "," in word:
             word = word.replace(" ", "")
             word = word.split(",")
-            words = []
             for x in word:
-                words.append(x)
-                if words.count(x) > 1:
+                if word.count(x) > 1:
                     await ctx.send("Words cannot be added twice.", delete_after=5)
                     return
-            for x in words:
                 await db.execute("INSERT INTO curses (curse,guild) VALUES (?,?)", (x,guildid))
             await db.commit()
-        else:
-            await db.execute("INSERT INTO curses (curse,guild) VALUES (?,?)", (word,guildid))
-            await db.commit()
         await db.close()
     async def remove_banned_word(ctx, word, dir):
             db = await aiosqlite.connect("curse.db")
@@ -113,15 +105,23 @@ class curse():
             os.chdir(dir)
             try:
                 word = word.lower()
-                guildid = str(ctx.guild.id)
-                if "," in word:
-                    word = word.replace(" ", "")
-                    word = word.split(",")                  
-                    for x in word:
-                        await db.execute("DELETE FROM curses WHERE curse = ? and guild = ?", (x,guildid))
-                    await db.commit()
-                else:
-                    await db.execute("DELETE FROM curses WHERE curse = ? and guild = ?", (word,guildid))
+                word = word.replace(" ", "")
+                word = word.split(",")
+                in_db = False
+                async with db.execute("SELECT curse FROM curses WHERE guild = ?", (guildid,)) as cursor:
+                    async for entry in cursor:
+                        curse = entry[0]
+                        for x in word:
+                            if x == curse:
+                             in_db = True
+                if in_db == False:
+                    if len(word) > 1:
+                        await ctx.send("None of those words are in the list", delete_after=5)
+                    else:
+                        await ctx.send("This word is not in the list", delete_after=5)
+                    return 
+                for x in word:
+                    await db.execute("DELETE FROM curses WHERE curse = ? and guild = ?", (x,guildid))
                     await db.commit()
                 await db.close()
             except:
@@ -299,7 +299,8 @@ class warnings():
                     async for entry in cursor:
                         number += 1
                         embed.add_field(name=f"#{number} warning", value=f"Reason: {entry[0]}", inline=False)
-                    if number != 0:
+                    if number > 0:
+                        embed.set_footer(text=f"Total Warnings | {number}")
                         await ctx.send(embed=embed, reference= ctx.message.reference or ctx.message)
                     else:
                         await ctx.send(f"{user.mention} has no warnings", reference= ctx.message.reference or ctx.message)
@@ -312,56 +313,60 @@ class warnings():
         user = member
         guild = str(ctx.guild.id)
         member = str(member.id)
+        number = str(number)
         number = number.lower()
-        try:
-            if number == "all":
-                db = await aiosqlite.connect("warnings.db")
-                await db.execute("DELETE FROM warnings WHERE guild = ? and member_id = ?", (guild,member))
-                await db.commit()
-                await db.close()
-                await ctx.send(f"Cleared all warnings from {user.mention}", delete_after=7)
-            else:
-                if "," in number:
-                    number = number.replace(" ", "")
-                    number_list = number.split(",")
-                    number_list = list(map(int, number_list))
-                    number_list = sorted(number_list, reverse=True)
-                    db = await aiosqlite.connect("warnings.db")
-                    dict = {}
-                    async with db.execute("SELECT id,row_number() OVER (ORDER BY id) FROM warnings WHERE guild = ? and member_id = ?", (guild,member)) as cursor:
-                        async for entry in cursor:
-                            id,pos = entry
-                            pos = str(pos)
-                            dict.update({pos:id})
-                    for x in number_list:
-                        await db.execute("DELETE FROM warnings WHERE id = ?", (dict[str(x)],))
-                    await db.commit()
-                    await db.close()
-                    number_list = list(map(str, number_list))
-                    number_list = ", ".join(number_list)
-                    await ctx.send(f"Cleared warnings {number_list} from {user.mention}.", delete_after=7)
-                else:
-                    number = int(number)
-                    db = await aiosqlite.connect("warnings.db")
-                    dict = {}
-                    async with db.execute("SELECT id,row_number() OVER (ORDER BY id) FROM warnings WHERE guild = ? and member_id = ?", (guild,member)) as cursor:
-                        async for entry in cursor:
-                            id,pos = entry
-                            pos = str(pos)
-                            dict.update({pos:id})
-                    await db.execute("DELETE FROM warnings WHERE id = ?", (dict[str(number)],))
-                    await db.commit()
-                    await db.close()
-                    await ctx.send(f"Cleared {user.mention}'s #{number} warning.", delete_after=7)
-        except:
-            if number == "all":
-                await ctx.send(f"{user.mention} has no warnings.", delete_after=5)
-            else:
-                await ctx.send(f"{user.mention} does not have that many warnings.", delete_after=5)
-
-        
-
-    async def punish(ctx, member, dir, *args, one=None, two=None, three=None, four=None, five=None, six=None, seven=None, eight=None, nine=None, ten=None, remove_role=None, add_role=None, **kwargs):
+        db = await aiosqlite.connect("warnings.db")
+        async with db.execute("SELECT reason FROM warnings WHERE guild = ? and member_id = ?", (guild,member)) as cursor:
+            count = 0
+            async for entry in cursor:
+                count += 1
+        if count < 1:
+            await ctx.send(f"{user.mention} has no warnings.", delete_after=5)
+            return
+        if number == "all":
+            await db.execute("DELETE FROM warnings WHERE guild = ? and member_id = ?", (guild,member))
+            await db.commit()
+            await db.close()
+            await ctx.send(f"Cleared all warnings from {user.mention}", delete_after=7)
+            return
+        else:
+                try:
+                    if "," in number:
+                        number = number.replace(" ", "")
+                        number_list = number.split(",")
+                        number_list = list(map(int, number_list))
+                        number_list = sorted(number_list, reverse=True)
+                        dict = {}
+                        async with db.execute("SELECT id,row_number() OVER (ORDER BY id) FROM warnings WHERE guild = ? and member_id = ?", (guild,member)) as cursor:
+                            async for entry in cursor:
+                                id,pos = entry
+                                pos = str(pos)
+                                dict.update({pos:id})
+                        for x in number_list:
+                            await db.execute("DELETE FROM warnings WHERE id = ?", (dict[str(x)],))
+                        await db.commit()
+                        await db.close()
+                        number_list = list(map(str, number_list))
+                        number_list = ", ".join(number_list)
+                        await ctx.send(f"Cleared warnings {number_list} from {user.mention}.", delete_after=7)
+                    else:
+                        number = int(number)
+                        dict = {}
+                        async with db.execute("SELECT id,row_number() OVER (ORDER BY id) FROM warnings WHERE guild = ? and member_id = ?", (guild,member)) as cursor:
+                            async for entry in cursor:
+                                id,pos = entry
+                                pos = str(pos)
+                                dict.update({pos:id})
+                        await db.execute("DELETE FROM warnings WHERE id = ?", (dict[str(number)],))
+                        await db.commit()
+                        await db.close()
+                        await ctx.send(f"Cleared {user.mention}'s #{number} warning.", delete_after=7)
+                except:
+                    if number == "all":
+                        await ctx.send(f"{user.mention} has no warnings.", delete_after=5)
+                    else:
+                        await ctx.send(f"{user.mention} does not have that many warnings.", delete_after=5)
+    async def punish(ctx, member, dir, *args, one=None, two=None, three=None, four=None, five=None, six=None, seven=None, eight=None, nine=None, ten=None, eleven=None, twelve=None, thirteen=None, fourteen=None, fifteen=None, remove_role=None, add_role=None, **kwargs):
                     os.chdir(dir)
                     memberid = str(member.id)
                     guild = str(ctx.guild.id)
@@ -400,6 +405,21 @@ class warnings():
                     if warnings_number == 10:
                         warnings_number_str = ten
                         message = "You received your tenth warning."
+                    if warnings_number == 11:
+                        warnings_number_str = eleven
+                        message = "You received your eleventh warning."
+                    if warnings_number == 12:
+                        warnings_number_str = twelve
+                        message = "You received your twelfth warning."
+                    if warnings_number == 13:
+                        warnings_number_str = thirteen
+                        message = "You received your thirteenth warning."
+                    if warnings_number == 14:
+                        warnings_number_str = fourteen
+                        message = "You received your fourteenth warning."
+                    if warnings_number == 15:
+                        warnings_number_str = fifteen
+                        message = "You received your fifteenth warning."
                     if warnings_number_str == None:
                         return
                     if "temp" in warnings_number_str:
@@ -612,7 +632,10 @@ class rr():
         guild = str(ctx.guild.id)
         message_id = str(message_id)
         db = await aiosqlite.connect("rr.db")
-        await db.execute("DELETE FROM rr WHERE guild = ? and msg_id = ?", (guild,message_id))
+        message_id = message_id.replace(" ", "")
+        message_id = message_id.split(",")
+        for x in message_id:
+            await db.execute("DELETE FROM rr WHERE guild = ? and msg_id = ?", (guild,x))
         await db.commit()
         await db.close()
         await ctx.send(f"Delted reaction role info for {message_id}", delete_after=7)
@@ -625,16 +648,24 @@ class rr():
             number = 0
             async for entry in cursor:
                 number += 1
-                async with db.execute("SELECT role,emoji,channel FROM rr WHERE guild = ? and msg_id = ?", (guild,entry[0])) as f:
+                async with db.execute("SELECT role,emoji,channel,msg_id FROM rr WHERE guild = ? and msg_id = ?", (guild,entry[0])) as f:
                     msg = ""
                     async for entry in f:
-                        print(entry)
-                        role,emoji,channel = entry
+                        role,emoji,channel,msg_id = entry
                         channel = ctx.guild.get_channel(int(channel))
                         role = ctx.guild.get_role(int(role))
-                        msg += f"Emoji: {emoji} Role: {role.mention} Channel: #{channel} Message ID: {entry[0]}\n"
+                        try:
+                            role = role.mention
+                        except:
+                            role = "@deleted-role"
+                        try:
+                            channel = channel.mention
+                        except:
+                            channel = "#deleted-channel"
+                        msg += f"Emoji: {emoji} Role: {role} Channel: {channel} Message ID: {msg_id}\n"
                 embed.add_field(name=f"Reaction Role #{number}", inline=False, value=msg)
         if number > 0:
+            embed.set_footer(text=f"Total Reaction Roles | {number}")
             await ctx.send(embed=embed, reference= ctx.message.reference or ctx.message)
         else:
             await ctx.send("There are no reaction roles in this server.", delete_after=5)
